==> patch-2.5.5.3_1.zip: app/views/login/captcha.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form;
use Helpers\Session;
?>
<?php $session = new Session();?>
<?php
    /*$dCloudName = !empty(htmlentities($_GET['c'])) ? $_GET['c'] : $data['cloudName'];
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;*/
    $cloudName = CLOUD_NAME;
?>
<div class="container">
    <div class="row">
    </div>
    <?php if(!isMobile()){?> <br/><br/><br/> <?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6">
                        <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                        <!--<div class="success" style="display: none; color: green; margin-bottom: 10px;"></div>-->
                        <div id="status" style="display: none; color: green; margin-bottom: 10px;"></div>
                        <?=
                            Form::open(array(
                                //'action' => Url::basePath('captchaAuthenticate'),
                                'action' => Url::basePath('login'),
                                'method' => 'post',
                                'class' => 'captcha-form',
                                'csrf' => $data['csrf_token'],
                                'autocomplete' => 'off',
                                'data-parsley-validate' => true
                            ));
                        ?>
                        <div class="form-group" <?php if(enableRecaptcha == false){ ?> style="margin-top:20%;" <?php } ?>>
                            <label for="password"><?=Language::show('password', 'keywords');?></label>
                            <input type="password" class="form-control" name="password" id="password" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('password', 'keywords');?>" required autocomplete="off" autofocus>
                            <?php if(eyeOption == true){ ?>
                                <span toggle="#password" class="fa fa-fw fa-eye-slash field-icon toggle-password"></span>
                            <?php } ?>
                        </div>
                        <div id="captchaDiv">
                        <?php
                            global $image;
                            $image = imagecreatetruecolor(200, 50) or die("Cannot Initialize new GD image stream");
                            $background_color = imagecolorallocate($image, 255, 255, 255);
                            $text_color = imagecolorallocate($image, 0, 255, 255);
                            $line_color = imagecolorallocate($image, 64, 64, 64);
                            $pixel_color = imagecolorallocate($image, 0, 0, 255);
                            imagefilledrectangle($image, 0, 0, 200, 50, $background_color);
                            for ($i = 0; $i < 3; $i++) {
                                imageline($image, 0, rand() % 50, 200, rand() % 50, $line_color);
                            }
                            for ($i = 0; $i < 1000; $i++) {
                                imagesetpixel($image, rand() % 200, rand() % 50, $pixel_color);
                            }
                            $letters = $session->get('captcha-value');
                            //$letters = $data['letter'];
                            $len = strlen($letters);
                            $letter = $letters[rand(0, $len - 1)];
                            $text_color = imagecolorallocate($image, 0, 0, 0);
                            $word = "";
                            $font = '/var/www/portal/app/templates/default/css/fonts/monofont.ttf';
                            for ($i = 0; $i < strlen($letters); $i++) {
                                    $letter = $letters[$i];
                                    $letter = trim($letter);
                        //          imagestring($image, 8, 70 + ($i * 15), 20, $letter, $text_color);
                                    imagettftext($image, 36, 0, 70 + ($i * 15), 35, $text_color, $font, $letter);
                                $word .= $letter;
                            }
                            $images = glob("*.png");
                            foreach ($images as $image_to_delete) {
                                @unlink($image_to_delete);
                                }
                            imagepng($image, "image" . $session->get('countt') . ".png");
                        ?>
                        </div>
                        <?php if(enableRecaptcha == true){ ?>
                        <div class="from-group">
                            <label>Enter captcha shown below </label>
                            <input class="form-control" type="text" id="code" name="code" required autocomplete="off"/>
                            <!--<img id="captchaImage" src="image<?php echo $data['count'] ?>.png">-->
                            <span id="captchaSpan">
                                <img id="captchaImage" src="image<?=$session->get('countt')?>.png">
                            </span>
                            <span id="refreshSpan"><a class="loginCaptchaRefresh" id="loginCaptchaRefresh" style="margin-left:10px;"><i class="glyphicon glyphicon-refresh" title="refresh captcha"></i></a></span>
                        </div>
                        <?php }else{ ?>
                                <input class="form-control d-none hide" type="text" id="code" name="code" value="<?=$session->get('captcha-value')?>" autocomplete="off"/>
                        <?php } ?>
<?php if(enableRecaptcha == true){ ?>
                        <div class="row hide" style="margin-top:18%;">
                            <div class="col-lg-6">
                                <!--<div class="g-recaptcha" data-sitekey="<?php echo RECAPTCHA_SITE_KEY;?>"></div>-->
                                <div class="g-recaptcha" data-sitekey="6LdjbN0UAAAAAJJHP5ZaYSd4hBZSbwQ5eQ8xVcio"></div>
                            </div>
                        </div>
			<?php } ?>
<?php
                            $passwordReset = 'Yes';
                            if($data['aadEnabledEnv'] == 'true' && $data['SSO_ENABLED'] == 'No'){
                                $passwordReset = 'No';
                            }

?>
                        <?php if($passwordReset == 'Yes'){?>
                        <?php //if($data['aadEnabledEnv'] != 'true'){?>
                            <?php if(allowPasswordReset == true){?>
                                <div class="row">                           
                                    <div class="col-lg-6">
                                        <a class="passwordRest" style="cursor:pointer;">Reset My Password</a>
                                    </div>                            
                                </div>
                            <?php } ?>
                        <?php } ?>
                        </div>
                    <div class="col-lg-12" style="margin-top:20px;">
                        <div class="col-lg-10" style="margin-top:20px;">
                            <?php if(EULA_ENABLED == true){ ?>
                                <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by all terms and conditions of Parablu’s End User License Agreement, a copy of which can be found here <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
                            <?php } ?>
                            <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                        if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                                echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
                        </div>
                        <div class="col-lg-2">
                        <span class="pull-right"><button type="submit" class="loginCaptcha btn btn-primary pull-right"><?=Language::show('login', 'keywords');?></button></span>
                        </div>
                        <?=
                            Form::close();
                        ?>
                    </div>
</div>
            </div>
        </div>
    </div>
</div>
<script>
if(localStorage.getItem("login") == 'yes'){
        window.location = '/portal/'+localStorage.getItem("redirectUrl");
}
</script>

==> patch-2.5.5.3_7_2.zip: app/views/login/captcha.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form;
use Helpers\Session;
?>
<?php $session = new Session();?>
<?php
    /*$dCloudName = !empty(htmlentities($_GET['c'])) ? $_GET['c'] : $data['cloudName'];
    $cloudName = !empty($dCloudName) ? $dCloudName : CLOUD_NAME;*/
    $cloudName = CLOUD_NAME;
?>
<div class="container">
    <div class="row">
    </div>
    <?php if(!isMobile()){?> <br/><br/><br/> <?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6">
                        <div class="error" style="display: none; color: #f55753; margin-bottom: 10px;"></div>
                        <!--<div class="success" style="display: none; color: green; margin-bottom: 10px;"></div>-->
                        <div id="status" style="display: none; color: green; margin-bottom: 10px;"></div>
                        <?=
                            Form::open(array(
                                //'action' => Url::basePath('captchaAuthenticate'),
                                'action' => Url::basePath('login'),
                                'method' => 'post',
                                'class' => 'captcha-form',
                                'csrf' => $data['csrf_token'],
                                'autocomplete' => 'off',
                                'data-parsley-validate' => true
                            ));
                        ?>
                        <div class="form-group" <?php if(enableRecaptcha == false){ ?> style="margin-top:20%;" <?php } ?>>
                            <label for="password"><?=Language::show('password', 'keywords');?></label>
                            <input type="password" class="form-control" name="password" id="password" placeholder="<?=Language::show('enter_your', 'keywords');?> <?=Language::show('password', 'keywords');?>" required autocomplete="off" autofocus disabled>
                            <?php if(eyeOption == true){ ?>
                                <span toggle="#password" class="fa fa-fw fa-eye-slash field-icon toggle-password"></span>
                            <?php } ?>
                        </div>
			<div id="captchaDiv">
			<?php if($data['superAdmin'] == 'true'){ ?>
                        <div class="form-group accessKeyDiv">
                            <label for="accessKey">Enter One Time Access Code sent to the registered Email address - <a  id="generateOtpLink" style="cursor:pointer;">Resend One Time Access Code</a></label>
                            <input type="text" class="form-control" name="accessKey" id="accessKey" placeholder="<?=Language::show('Enter', 'keywords');?> <?=Language::show('One Time Access Code', 'keywords');?>" required autocomplete="off">
                        </div>
                        <?php } ?>
                        <?php
                            global $image;
                            $image = imagecreatetruecolor(200, 50) or die("Cannot Initialize new GD image stream");
                            $background_color = imagecolorallocate($image, 255, 255, 255);
                            $text_color = imagecolorallocate($image, 0, 255, 255);
                            $line_color = imagecolorallocate($image, 64, 64, 64);
                            $pixel_color = imagecolorallocate($image, 0, 0, 255);
                            imagefilledrectangle($image, 0, 0, 200, 50, $background_color);
                            for ($i = 0; $i < 3; $i++) {
                                imageline($image, 0, rand() % 50, 200, rand() % 50, $line_color);
                            }
                            for ($i = 0; $i < 1000; $i++) {
                                imagesetpixel($image, rand() % 200, rand() % 50, $pixel_color);
                            }
                            $letters = $session->get('captcha-value');
                            //$letters = $data['letter'];
                            $len = strlen($letters);
                            $letter = $letters[rand(0, $len - 1)];
                            $text_color = imagecolorallocate($image, 0, 0, 0);
                            $word = "";
                            $font = '/var/www/portal/app/templates/default/css/fonts/monofont.ttf';
                            for ($i = 0; $i < strlen($letters); $i++) {
                                    $letter = $letters[$i];
                                    $letter = trim($letter);
                        //          imagestring($image, 8, 70 + ($i * 15), 20, $letter, $text_color);
                                    imagettftext($image, 36, 0, 70 + ($i * 15), 35, $text_color, $font, $letter);
                                $word .= $letter;
                            }
                            $images = glob("*.png");
                            foreach ($images as $image_to_delete) {
                                @unlink($image_to_delete);
                                }
                            imagepng($image, "image" . $session->get('countt') . ".png");
                        ?>
                        </div>
                        <?php if(enableRecaptcha == true){ ?>
                        <div class="from-group">
                            <label>Enter captcha shown below </label>
                            <input class="form-control" type="text" id="code" name="code" required autocomplete="off"/>
                            <!--<img id="captchaImage" src="image<?php echo $data['count'] ?>.png">-->
                            <span id="captchaSpan">
                                <img id="captchaImage" src="image<?=$session->get('countt')?>.png">
                            </span>
                            <span id="refreshSpan"><a class="loginCaptchaRefresh" id="loginCaptchaRefresh" style="margin-left:10px;"><i class="glyphicon glyphicon-refresh" title="refresh captcha"></i></a></span>
                        </div>
                        <?php }else{ ?>
                                <input class="form-control d-none hide" type="text" id="code" name="code" value="<?=$session->get('captcha-value')?>" autocomplete="off"/>
                        <?php } ?>
<?php if(enableRecaptcha == true){ ?>
                        <div class="row hide" style="margin-top:18%;">
                            <div class="col-lg-6">
                                <!--<div class="g-recaptcha" data-sitekey="<?php echo RECAPTCHA_SITE_KEY;?>"></div>-->
                                <div class="g-recaptcha" data-sitekey="6LdjbN0UAAAAAJJHP5ZaYSd4hBZSbwQ5eQ8xVcio"></div>
                            </div>
                        </div>
			<?php } ?>
<?php
                            $passwordReset = 'Yes';
                            if($data['aadEnabledEnv'] == 'true' && $data['SSO_ENABLED'] == 'No'){
                                $passwordReset = 'No';
                            }

?>
                        <?php if($data['superAdmin'] != 'true'){ ?>
                            <?php if(allowPasswordReset == true){?>
                                <div class="row">                           
                                    <div class="col-lg-6">
                                        <a class="passwordRest" style="cursor:pointer;">Reset My Password</a>
                                    </div>                            
                                </div>
                            <?php } ?>
                        <?php } ?>
                        </div>
                    <div class="col-lg-12" style="margin-top:20px;">
                        <div class="col-lg-10" style="margin-top:20px;">
                            <?php if(EULA_ENABLED == true){ ?>
                                <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by the terms and conditions of our End User Licensing Agreement and other policies which can be found under <span class="legal"></span></h4>
                            <?php } ?>
                            <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                        if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                                echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
                        </div>
                        <div class="col-lg-2">
                        <span class="pull-right"><button type="submit" class="loginCaptcha btn btn-primary pull-right"><?=Language::show('login', 'keywords');?></button></span>
                        </div>
                        <?=
                            Form::close();
                        ?>
                    </div>
</div>
            </div>
        </div>
    </div>
</div>
<script>
if(localStorage.getItem("login") == 'yes'){
	var env = $('.cloud_url').html();
        env = $('.protocol').html()+env;
        window.location = env+'/portal/'+localStorage.getItem("redirectUrl");	
}
</script>
